@@ -11,7 +11,7 @@ class Log extends React.Component {
     super()
 
     this.state = {
-      jobs: []
+      logs: " "
     }
   }
 
@@ -22,11 +22,6 @@ class Log extends React.Component {
 
   async getLog(schedule, command){
 
-    const dataToSend = { 
-      command,
-      schedule
-    };
-
     try {
       const reply = await requestAPI(`log?command=${command}&schedule=${schedule}`, {
         method: 'GET'
@@ -40,7 +35,7 @@ class Log extends React.Component {
 
     } catch (reason) {
       console.error(
-        `Error sending delete: ${reason}`
+        `Error viewing log: ${reason}`
       );
     }
 
@@ -48,8 +43,8 @@ class Log extends React.Component {
 
   render() {
     return (
-      <div style={{"height":"100%"}}>
-        <LazyLog text={this.state.logs} />
+      <div style={{ height: 800 }}>
+        <LazyLog stream text={this.state.logs} />
       </div >
     )
   }
@@ -71,4 +66,4 @@ export class ViewLog extends ReactWidget {
   render() {
     return <Log command={this.command} schedule={this.schedule}/>;
   }
-}
\ No newline at end of file
+}
